"""
A2A (Agent-to-Agent) schema package.

This package contains Pydantic schema definitions for the A2A protocol.
"""

from src.schemas.a2a.types import (
    TaskState,
    TextPart,
    FileContent,
    FilePart,
    DataPart,
    Part,
    Message,
    TaskStatus,
    Artifact,
    Task,
    TaskStatusUpdateEvent,
    TaskArtifactUpdateEvent,
    AuthenticationInfo,
    PushNotificationConfig,
    TaskIdParams,
    TaskQueryParams,
    TaskSendParams,
    TaskPushNotificationConfig,
    JSONRPCMessage,
    JSONRPCRequest,
    JSONRPCResponse,
    JSONRPCError,
    SendTaskRequest,
    SendTaskResponse,
    SendTaskStreamingRequest,
    SendTaskStreamingResponse,
    GetTaskRequest,
    GetTaskResponse,
    CancelTaskRequest,
    CancelTaskResponse,
    SetTaskPushNotificationRequest,
    SetTaskPushNotificationResponse,
    GetTaskPushNotificationRequest,
    GetTaskPushNotificationResponse,
    TaskResubscriptionRequest,
    A2ARequest,
    AgentProvider,
    AgentCapabilities,
    AgentAuthentication,
    AgentSkill,
    AgentCard,
)

from src.schemas.a2a.exceptions import (
    JSONParseError,
    InvalidRequestError,
    MethodNotFoundError,
    InvalidParamsError,
    InternalError,
    TaskNotFoundError,
    TaskNotCancelableError,
    PushNotificationNotSupportedError,
    UnsupportedOperationError,
    ContentTypeNotSupportedError,
    A2AClientError,
    A2AClientHTTPError,
    A2AClientJSONError,
    MissingAPIKeyError,
)

from src.schemas.a2a.validators import (
    validate_base64,
    validate_file_content,
    validate_message_parts,
    text_to_parts,
    parts_to_text,
)

__all__ = [
    # From types
    "TaskState",
    "TextPart",
    "FileContent",
    "FilePart",
    "DataPart",
    "Part",
    "Message",
    "TaskStatus",
    "Artifact",
    "Task",
    "TaskStatusUpdateEvent",
    "TaskArtifactUpdateEvent",
    "AuthenticationInfo",
    "PushNotificationConfig",
    "TaskIdParams",
    "TaskQueryParams",
    "TaskSendParams",
    "TaskPushNotificationConfig",
    "JSONRPCMessage",
    "JSONRPCRequest",
    "JSONRPCResponse",
    "JSONRPCError",
    "SendTaskRequest",
    "SendTaskResponse",
    "SendTaskStreamingRequest",
    "SendTaskStreamingResponse",
    "GetTaskRequest",
    "GetTaskResponse",
    "CancelTaskRequest",
    "CancelTaskResponse",
    "SetTaskPushNotificationRequest",
    "SetTaskPushNotificationResponse",
    "GetTaskPushNotificationRequest",
    "GetTaskPushNotificationResponse",
    "TaskResubscriptionRequest",
    "A2ARequest",
    "AgentProvider",
    "AgentCapabilities",
    "AgentAuthentication",
    "AgentSkill",
    "AgentCard",
    # From exceptions
    "JSONParseError",
    "InvalidRequestError",
    "MethodNotFoundError",
    "InvalidParamsError",
    "InternalError",
    "TaskNotFoundError",
    "TaskNotCancelableError",
    "PushNotificationNotSupportedError",
    "UnsupportedOperationError",
    "ContentTypeNotSupportedError",
    "A2AClientError",
    "A2AClientHTTPError",
    "A2AClientJSONError",
    "MissingAPIKeyError",
    # From validators
    "validate_base64",
    "validate_file_content",
    "validate_message_parts",
    "text_to_parts",
    "parts_to_text",
]
